/*
 * $Header: /a/beepbeep/navy/homes/zeus/Zeus/SRC/RCS/prot.h,v 0.0 1993/07/14
 * 13:42:50 bampton Exp bampton $
 * 
 * $Log: prototypes.h,v $
 * Revision 2.47  1998/04/15 21:36:07  zeus
 * *** empty log message ***
 *
 * Revision 2.46  1997/04/18 12:16:55  zeus
 * Revision 2.45  1997/01/01  00:14:27  zeus
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * Revision 2.39  1993/10/28  22:31:20  bampton
 * Revision 2.38  1993/09/27  17:15:54  bampton
 * Revision 2.37  1993/09/07  20:50:32  bampton
 * Revision 2.34  1993/08/09  23:06:20  bampton
 * Revision 2.33  1993/08/03  23:10:13  bampton
 * Revision 2.30  1993/07/14  14:59:26  bampton Full RCS version
 * Revision 0.0  1993/07/14  13:42:50  bampton RCS prototype.
 * 
 * 
 */

/* Function prototypes for various functions */
/* Note: These are functions that are accessed either from a file with
a main(), or by a number of programs. Localized functions should be
placed in the relevant header file.

Note: Some of these functions should probably have their header file
location moved as well... */

void            addlist (void *_base, void *_p);
int             canseeplanet (player * P, planet * p, int flag);
double          dist (planet * p1, planet * p2);
void            enterturn (int i);
void            fpf (FILE * f, double x);
double          frand (double x);
void            freelist (void *base);
double          getf (void);
double          getf2 (void);
int             geti (void);
void            getstr (void);
void            gm_map (void);
planet         *inputplanet (planet * head, char *prompt);
player         *inputplayer (player * head, char *prompt);
void            inputpr (void);
void            loadgame (void);
int             opengame (void);
void            planet_list (void);
void            player_status (void);
int             ptonum (void *base, void *target);
void            removelist (void *_base, void *_p);
void            report (player * P);
long            rnd (int x);
void            savegame (void);
void            Send (group * g, planet * p);
double          shipmass (group * g);
double          typemass (shiptype * t);
void            showfull (void);
int             hstricmp (const char *s1, const char *s2);
void            unloadgroup (group * g, player * P);
void           *alloc (unsigned int bytes);
void           *nametop (void *head, char *s);
void           *numtop (void *base, int n);
double          weaponmass (shiptype * t);
shiptype       *inputshiptype (player * P);
void            sortplanets (void);
void            addplayer (void);
planet         *addplanet (void);
void            printproduction (planet * p);
double          produce_mass (planet * p);
double          produce_cap (planet * p);
double          produce_mat (planet * p);
double          Ftrunc (double x);
void            dip_status (player * P1, player * P2);
double          effective_ind (planet * p);
void            delete_player (player * P, int force);
double          cargospace (group * g);
void            version_info (void);
void            full_version (void);
void            forecast_report (player *P);
void            build_seen_list (player *P);
double          upgrade_cost (player *P,group *g);
void            forward_list(void);
double          downgrade_cost (player *P, shiptype *T, planet *p);
void            sterilize (planet *p);
void            hstrncpy (char *a, const char *b, const int sz);
